import 'package:flutter/material.dart';
import 'package:navigation_tabbar/enums/animation_type.dart';
import 'package:navigation_tabbar/enums/navigation_tab_bar_style.dart';
import 'package:navigation_tabbar/enums/tab_indicator_style.dart';
import 'package:navigation_tabbar/model/tab_item.dart';
import 'package:navigation_tabbar/tab_bar.dart';
import 'package:flutter_animator/flutter_animator.dart';

class TabWidgetItem extends StatelessWidget {
  final TabItem item;
  final Function onTap;
  final NavigationTabBar tabBar;
  final int currentIndex;
  final int tabIndex;
  const TabWidgetItem(
      {Key? key,
      required this.item,
      required this.onTap,
      required this.tabBar,
      this.currentIndex = 0,
      this.tabIndex = 0})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      height: 50,
      width: 55,
      child: GestureDetector(
        onTap: () {
          onTap();
        },
        child: Stack(
          children: [
            tabBar.tabIndicatorStyle == TabIndicatorStyle.retangle
                ? Positioned.fill(
                    child: Align(
                      alignment: Alignment.topCenter,
                      child: Container(
                          height: tabBar.tabIndicatorHeight,
                          decoration: BoxDecoration(
                              color: currentIndex == tabIndex
                                  ? tabBar.tabSelectedColor
                                  : Colors.white,
                              borderRadius: BorderRadius.circular(
                                  tabBar.tabBorderRadius)),
                          width: tabBar.iconSize),
                    ),
                  )
                : const SizedBox(),
            currentIndex == tabIndex ? animationView() : itemWidget(),
          ],
        ),
      ),
    );
  }

  Widget animationView() {
    switch (tabBar.animationType) {
      case AnimationType.fadein:
        return FadeIn(child: itemWidget());
      case AnimationType.pusle:
        return Pulse(child: itemWidget());
      case AnimationType.tada:
        return Tada(child: itemWidget());
      case AnimationType.swing:
        return Swing(child: itemWidget());
      case AnimationType.beat:
        return HeartBeat(child: itemWidget());
      case AnimationType.bounce:
        return BounceIn(child: itemWidget());
      default:
        return FadeIn(child: itemWidget());
    }
  }

  Column itemWidget() {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Image.asset(
          item.icon,
          width: tabBar.iconSize,
          height: tabBar.iconSize,
          color: currentIndex == tabIndex
              ? tabBar.tabSelectedColor
              : tabBar.tabUnSelectedColor,
        ),
        tabBar.tabIndicatorStyle == TabIndicatorStyle.dot
            ? Align(
                alignment: Alignment.topCenter,
                child: Container(
                  margin: const EdgeInsets.only(top: 2),
                  height: tabBar.tabIndicatorHeight,
                  decoration: BoxDecoration(
                      color: currentIndex == tabIndex
                          ? tabBar.tabSelectedColor
                          : Colors.white,
                      borderRadius:
                          BorderRadius.circular(tabBar.tabBorderRadius)),
                  width: tabBar.tabIndicatorHeight,
                ),
              )
            : tabBar.tabBarStyle == NavigationTabBarStyle.icon
                ? const SizedBox()
                : Text(
                    item.title!,
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        fontSize: tabBar.fontSize,
                        color: currentIndex == tabIndex
                            ? tabBar.tabSelectedColor
                            : tabBar.tabUnSelectedColor),
                  )
      ],
    );
  }
}
